<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="500px"
            :before-close="handleClose"
        >
            <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-position="top">
                <el-form-item label="评价组成员:" prop="person.name">
                  <el-input
                      v-model.trim="state.form.person.name"
                      size="large"
                      placeholder="请选择评价组成员"
                      @focus="openExperts('评价组成员')"
                  >
                    <template #append>
                      <el-button :icon="Search" @click="openExperts('评价组成员')"/>
                    </template>
                  </el-input>
                </el-form-item>
                <el-form-item label="工作类型:" prop="jobType">
                  <el-select v-model="state.form.jobType" placeholder="工作类型" style="width: 100%" size="large">
                    <el-option v-for="(item,index) in props.typeList" :key="index" :label="item.label" :value="item.value"/>
                  </el-select>
                </el-form-item>
<!--                <el-form-item label="专业能力:" prop="person.major">-->
<!--                  <el-select v-model="state.form.person.majorName" placeholder="专业能力" style="width: 100%" size="large" @change="getCerNo">-->
<!--                    <el-option v-for="(item,index) in state.form.person.majorNames" :key="index" :label="item" :value="item"/>-->
<!--                  </el-select>-->
<!--                </el-form-item>-->
<!--                <el-form-item label="资格证书:" prop="person.certificateNo">-->
<!--                  <el-input-->
<!--                      v-model="state.form.person.certificateNo"-->
<!--                      size="large"-->
<!--                      readonly-->
<!--                  />-->
<!--                </el-form-item>-->
              <el-form-item label="承担工作:" prop="work">
                <el-select v-model="state.form.work" multiple placeholder="承担工作" style="width: 100%" size="large">
                  <el-option v-for="item in props.workList" :key="item.value" :label="item.label" :value="item.value"/>
                </el-select>
              </el-form-item>
              <el-form-item label="承诺后期前往现场勘验:" prop="laterPromise">
                <el-radio-group v-model="state.form.laterPromise" size="large">
                  <el-radio :label="1" size="large">是</el-radio>
                  <el-radio :label="0" size="large">否</el-radio>
                </el-radio-group>
              </el-form-item>
              <el-form-item label="未到现场勘验原因:">
                <el-input v-model.trim="state.form.reason" maxlength="30" show-word-limit type="text" size="large"/>
              </el-form-item>
            </el-form>
            <template #footer>
                    <span class="dialog-footer">
                        <el-button @click="handleClose" size="default">取 消</el-button>
                        <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
                    </span>
            </template>
          <experts-list ref="expertsListRef" @getName="getSelected"></experts-list>
        </el-dialog>
    </div>
</template>
<script setup>
import {defineProps, nextTick, reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {Search} from '@element-plus/icons-vue'
import {addWorks, editWorks} from "@/api/projectManage/evaPlan"
import ExpertsList from "./expertsList"

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const expertsListRef = ref()
const props = defineProps(['workList','typeList'])
const emit = defineEmits(["getList"]);
const state = reactive({
    form: {
      id: null,
      person: {
        name: '',
        // major: {},
        // certificateNo: '',
        // certs: '',
        // majorName: '',
        // majorNames: [],
        // ids: []
      },
      personId: null,
      jobType: null,
      projectId: null,
      informed: 0,
      work: [],
      laterPromise: 0,
      reason: ''
    },
    formRules:{
        'person.name': [{ required: true, message: '请选择评价组成员', trigger: 'change' }],
        'person.major': [{ required: true, message: '请选择专业能力', trigger: 'blur' }],
        work: [{ required: true, message: '请选择承担工作', trigger: 'blur' }],
        jobType: [{ required: true, message: '请选择工作类型', trigger: 'blur' }]
    },

})

const openDialog = async (type, value,projectId) => {
    title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
    state.form.projectId = projectId
    if(type == 'add'){
      nextTick(()=>{
        busRef.value.resetFields()
      })
    }else if(type === 'edit') {
      state.form = JSON.parse(JSON.stringify(value))
      state.form.work = value.work.split(',')
      state.form.laterPromise = value.laterPromise?1:0
    }
    dialogVisible.value = true;
}

const openExperts = (type) =>{
  expertsListRef.value.openDialog(type)
}

const getSelected = (type,obj)=>{
    state.form.person.name = obj.name
    state.form.personId = obj.id
    // state.form.person.certs = obj.certificateNo
    // state.form.person.majorNames = obj.majorNames
    // state.form.person.ids = obj.major.split(',')
}

// const getCerNo = () =>{
//   const i = state.form.person.majorNames.indexOf(state.form.person.majorName)
//   const obj = JSON.parse(state.form.person.certs)
//   state.form.person.certificateNo = Object.values(obj)[i]
//   state.form.person.major[state.form.person.ids[i]] = state.form.person.certificateNo
// }

const onSubmit = async () => {
    const valid = await busRef.value.validate();
    if(valid){
        if(title.value === '新增'){
            const {id,work,...data} = state.form
            data['work'] =  state.form.work.join(',')
            // const {name,major,...rest} = state.form.person
            // data.person = { name,major }
            // data.person.major =  JSON.stringify(state.form.person.major)
            const res = await addWorks(data)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '新增成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            busRef.value.clearValidate();
            busRef.value.resetFields()
            dialogVisible.value = false;
        }else if(title.value === '编辑'){
            const {...data} = state.form
            data['work'] =  state.form.work.join(',')
            const res = await editWorks(data)
            if(res.code === 200){
                ElMessage({
                    type: 'success',
                    message: '修改成功'
                });
            }else{
                ElMessage.warning(res.message)
            }
            emit("getList")
            busRef.value.clearValidate();
            busRef.value.resetFields()
            dialogVisible.value = false;
        }
    }
}

const handleClose = () => {
    busRef.value.clearValidate();
    busRef.value.resetFields()
    dialogVisible.value = false;
}

defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }
    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
</style>
